@@ -210,7 +210,7 @@ class Shop(Service):
         """
         return self._callapi("shop/reviews/submit", post=postObject)
 
-    def get_reviews(self, limit=None, offset=None):
+    def get_reviews(self, limit=None, offset=None, product_id=None):
         """
         :rtype : Collection|list of Review
         """
@@ -218,7 +218,8 @@ class Shop(Service):
             "shop/reviews",
             get={
                 "limit": limit,
-                "offset": offset})
+                "offset": offset,
+                "product_id": product_id})
 
     def get_cash_salons_cities(self, country_id):
         """
